HAWC2 tools
===========================

``wetb`` includes functions to help with the writing of HAWC2 input
files, also know as htc files. The documentation is in a Jupyter
notebook format. You can download the source notebooks from the
``wetb`` repository, under ``docs/source/hawc2``.

.. toctree::
    :caption: HAWC2

    InputFileWriting_nb
    RunningSimulations_nb
    RunningSimulationsJess_nb